% demo for tmikku ARTA data

% prepare:
clear all;
close all;
files = dir ('*.pir'); % list of PIR files:
N = length (files); % number of IR files

% load and process data from PIR files:

for k = 1:N

	% load data from PIR file:
	[t,IR,info] = mataa_import_PIR (files(k).name);

	% process and plot impulse response (IR):
	[IR,t] = mataa_signal_crop (IR,t,8.5E-3,13.2E-3); % crop anechoic IR part from 8.5...13.2 ms
	IR = IR / info.devicesens; % convert IR from V to Pa
	figure (1); plot (t*1000,IR); hold on

	% convert IR to frequency response:
	[mag,phase,f,unit_mag] = mataa_IR_to_FR (IR,t,1/12,'Pa'); % calculate frequency response
	figure (2); semilogx (f,mag); hold on

	% convert IR to frequency response (with DC / low frequency trends removed):
	[mag,phase,f,unit_mag] = mataa_IR_to_FR (detrend(IR),t,1/24,'Pa'); % calculate frequency response
	figure (3); semilogx (f,mag); hold on
end

% clean up
figure (1); hold off; xlabel ('Time (ms)'); ylabel ('Pressure (Pa)'); title ('Impulse response data (anechoic)')
figure (2); hold off; xlabel ('Frequency (Hz)'); ylabel ('SPL (dB-SPL)'); title ('SPL (incl. DC + LF)')
figure (3); hold off; xlabel ('Frequency (Hz)'); ylabel ('SPL (dB-SPL)'); title ('SPL (no DC + LF trends)')

